
:autogenerated:
..
    This file is autogenerated by `generate_custom_files` in conf.py,
    and ought to be generated via building the documentation through Sphinx, e.g.
    with `sphinx-build ./web ./build` from the root directory.

nltk.test.unit.lm package
=========================

.. automodule:: nltk.test.unit.lm
    :members:
    :undoc-members:
    :show-inheritance:




**********
Submodules
**********

    .. toctree::
       :maxdepth: 1

       nltk.test.unit.lm.test_counter
       nltk.test.unit.lm.test_models
       nltk.test.unit.lm.test_preprocessing
       nltk.test.unit.lm.test_vocabulary